==> kvision-server-spring-boot-4.2.0-sources.jar: commonMain/io/kvision/remote/Annotations.kt <==
/*
 * Copyright (c) 2017-present Robert Jaros
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package io.kvision.remote

@OptIn(ExperimentalMultiplatform::class)
@OptionalExpectation
expect annotation class Id()

@OptIn(ExperimentalMultiplatform::class)
@OptionalExpectation
expect annotation class Transient()

@OptIn(ExperimentalMultiplatform::class)
@OptionalExpectation
expect annotation class Table(val value: String)

@OptIn(ExperimentalMultiplatform::class)
@OptionalExpectation
expect annotation class Column(val value: String)

@OptIn(ExperimentalMultiplatform::class)
@OptionalExpectation
expect annotation class PersistenceConstructor()

==> kvision-server-spring-boot-5.15.0-sources.jar: commonMain/io/kvision/remote/Annotations.kt <==
/*
 * Copyright (c) 2017-present Robert Jaros
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package io.kvision.remote

@OptIn(ExperimentalMultiplatform::class)
@OptionalExpectation
expect annotation class Id()

@OptIn(ExperimentalMultiplatform::class)
@OptionalExpectation
expect annotation class Transient()

@OptIn(ExperimentalMultiplatform::class)
@OptionalExpectation
expect annotation class Table(val value: String, val name: String, val schema: String)

@OptIn(ExperimentalMultiplatform::class)
@OptionalExpectation
expect annotation class Column(val value: String)

@OptIn(ExperimentalMultiplatform::class)
@OptionalExpectation
@Deprecated("Use PersistenceCreator instead", replaceWith = ReplaceWith("PersistenceCreator"))
expect annotation class PersistenceConstructor()

@OptIn(ExperimentalMultiplatform::class)
@OptionalExpectation
expect annotation class PersistenceCreator()

@OptIn(ExperimentalMultiplatform::class)
@OptionalExpectation
expect annotation class Value(val value: String)

@OptIn(ExperimentalMultiplatform::class)
@OptionalExpectation
expect annotation class Version()
